@@ -56,8 +56,8 @@ define('M3_TITLE_BRACKET_END',		'」');					// タイトルを括弧表記する
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'2.15.5');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2016/1/9');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'2.15.6');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2016/1/18');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -249,6 +249,8 @@ define('M3_VIEW_TYPE_NEWS',			'news');				// 新着情報
 define('M3_VIEW_TYPE_COMMENT',		'comment');				// コメント
 define('M3_VIEW_TYPE_EVENTENTRY',	'evententry');			// イベント予約
 define('M3_VIEW_TYPE_BANNER',		'banner');				// バナー
+// ジョブタイプ
+define('M3_JOB_TYPE_MAIL',			'mail');				// メール配信(会員情報に付属)
 
 // すべての機能タイプ
 $M3_ALL_FEATURE_TYPE	= array(	M3_VIEW_TYPE_DASHBOARD,			// ダッシュボード
