@@ -23,9 +23,9 @@ INSERT INTO _nav_item
 (ni_nav_id,  ni_id, ni_index, ni_url,        ni_name, ni_help_body) VALUES
 ('helplink', 1,     1,        '',       '使い方を簡単に理解するには？', '管理画面からは変更できません。チュートリアルマニュアル(http://doc.magic3.org/index.php?%E3%83%81%E3%83%A5%E3%83%BC%E3%83%88%E3%83%AA%E3%82%A2%E3%83%AB)を参考にします。'),
 ('helplink', 2,     2,        'task=configsite',       'サイト運用に必要な最小限の設定を行うには？', '「サイト情報」の必須項目を設定します。'),
-('helplink', 3,     3,        'task=initwizard_content',       '表示するコンテンツや機能を選択するには？', '「システム初期化ウィザード」の「コンテンツ」画面を設定し、次へ進みます。'),
-('helplink', 4,     4,        'task=initwizard_page2',       'デフォルトページを変更するには？', '「システム初期化ウィザード」の「ページ2」画面を設定し、次へ進みます。'),
-('helplink', 5,     5,        'task=initwizard_menu',       'メニューを階層化して定義するには？', '「システム初期化ウィザード」の「メニュー」画面を設定し、次へ進みます。'),
+('helplink', 3,     3,        'task=initwizard_content',       '表示するコンテンツや機能を選択するには？', '「管理画面カスタムウィザード」の「コンテンツ」画面を設定し、次へ進みます。'),
+('helplink', 4,     4,        'task=initwizard_page2',       'デフォルトページを変更するには？', '「管理画面カスタムウィザード」の「ページ2」画面を設定し、次へ進みます。'),
+('helplink', 5,     5,        'task=initwizard_menu',       'メニューを階層化して定義するには？', '「管理画面カスタムウィザード」の「メニュー」画面を設定し、次へ進みます。'),
 ('helplink', 6,     6,        'task=installdata',       'サンプルデータをインストールするには？', '「データインストール」画面からインストールするデータを選択し「インストール」ボタンを押します。公式サイトのデータを取得することも出来ます。'),
 ('helplink', 7,     7,        'task=templist',       'テンプレートを追加するには？', '「テンプレート管理」画面の「アップロード」ボタンからZIP圧縮形式のテンプレートを追加します。'),
 ('helplink', 8,     8,        '',                    'テンプレートを作成するには？', 'Artisteer(http://www.artisteer.com/)やThemler(https://themler.com/)などのツールが利用できます。Joomla!タイプでテンプレートを作成します。'),
