@@ -2,10 +2,10 @@
  * jqPlot
  * Pure JavaScript plotting plugin using jQuery
  *
- * Version: 1.0.7
- * Revision: 1224
+ * Version: 1.0.4
+ * Revision: 1120
  *
- * Copyright (c) 2009-2013 Chris Leonello
+ * Copyright (c) 2009-2012 Chris Leonello
  * jqPlot is currently available for use in all personal or commercial projects 
  * under both the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL 
  * version 2.0 (http://www.gnu.org/licenses/gpl-2.0.html) licenses. This means that you can 
@@ -155,7 +155,7 @@
             labelIdx = p.seriesLabelIndex;
         }
         else if (this.renderer.constructor === $.jqplot.BarRenderer && this.barDirection === 'horizontal') {
-           labelIdx = (this._plotData[0].length < 3) ? 0 : this._plotData[0].length -1;
+            labelIdx = 0;
         }
         else {
             labelIdx = (this._plotData.length === 0) ? 0 : this._plotData[0].length -1;
@@ -294,11 +294,13 @@
             for (var i=0, l=p._labels.length; i < l; i++) {
                 var label = p._labels[i];
                 
-                if (label == null || (p.hideZeros && parseInt(label, 10) == 0)) {
-                    continue;
+                if (p.hideZeros && parseInt(p._labels[i], 10) == 0) {
+                    label = '';
                 }
                 
-                label = p.formatter(p.formatString, label);
+                if (label != null) {
+                    label = p.formatter(p.formatString, label);
+                } 
 
                 helem = document.createElement('div');
                 p._elems[i] = $(helem);
